package com.ruoyi.rocketmq.controller;

import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.rocketmq.domain.InitialSystemOtherCollectData;
import com.ruoyi.rocketmq.service.IInitialSystemOtherCollectDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;

/**
 * 交换机系统其他信息采集数据Controller
 * 
 * @author gyt
 * @date 2025-09-23
 */
@RestController
@RequestMapping("/systemOtherCollectData")
public class InitialSystemOtherCollectDataController extends BaseController
{
    @Autowired
    private IInitialSystemOtherCollectDataService initialSystemOtherCollectDataService;

    /**
     * 查询交换机系统其他信息采集数据列表
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:list")
    @GetMapping("/list")
    public TableDataInfo list(InitialSystemOtherCollectData initialSystemOtherCollectData)
    {
        startPage();
        List<InitialSystemOtherCollectData> list = initialSystemOtherCollectDataService.selectInitialSystemOtherCollectDataList(initialSystemOtherCollectData);
        return getDataTable(list);
    }

    /**
     * 导出交换机系统其他信息采集数据列表
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:export")
    @Log(title = "交换机系统其他信息采集数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, InitialSystemOtherCollectData initialSystemOtherCollectData)
    {
        List<InitialSystemOtherCollectData> list = initialSystemOtherCollectDataService.selectInitialSystemOtherCollectDataList(initialSystemOtherCollectData);
        ExcelUtil<InitialSystemOtherCollectData> util = new ExcelUtil<InitialSystemOtherCollectData>(InitialSystemOtherCollectData.class);
        util.exportExcel(response, list, "交换机系统其他信息采集数据数据");
    }

    /**
     * 获取交换机系统其他信息采集数据详细信息
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(initialSystemOtherCollectDataService.selectInitialSystemOtherCollectDataById(id));
    }

    /**
     * 新增交换机系统其他信息采集数据
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:add")
    @Log(title = "交换机系统其他信息采集数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody InitialSystemOtherCollectData initialSystemOtherCollectData)
    {
        return toAjax(initialSystemOtherCollectDataService.insertInitialSystemOtherCollectData(initialSystemOtherCollectData));
    }

    /**
     * 修改交换机系统其他信息采集数据
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:edit")
    @Log(title = "交换机系统其他信息采集数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody InitialSystemOtherCollectData initialSystemOtherCollectData)
    {
        return toAjax(initialSystemOtherCollectDataService.updateInitialSystemOtherCollectData(initialSystemOtherCollectData));
    }

    /**
     * 删除交换机系统其他信息采集数据
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:remove")
    @Log(title = "交换机系统其他信息采集数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(initialSystemOtherCollectDataService.deleteInitialSystemOtherCollectDataByIds(ids));
    }
    /**
     * 查询系统其他信息基础数据
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:list")
    @PostMapping("/getMontiorMsg")
    public AjaxResult getMontiorMsg(@RequestBody InitialSystemOtherCollectData initialSystemOtherCollectData)
    {
        Map list = initialSystemOtherCollectDataService.getMonitorMsg(initialSystemOtherCollectData);
        return success(list);
    }
    /**
     * 查询系统登陆用户数(个)监控信息列表并封装为多折线ECharts图表数据
     * @param initialSystemOtherCollectData
     * @return
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:list")
    @PostMapping("/systemUserNumEcharts")
    public AjaxResult systemUserNumEcharts(@RequestBody InitialSystemOtherCollectData initialSystemOtherCollectData) {
        Map<String, Object> echartsData = initialSystemOtherCollectDataService.systemUserNumEcharts(initialSystemOtherCollectData);
        return success(echartsData);
    }
    /**
     * 查询交换卷文件的可用空间监控信息列表并封装为多折线ECharts图表数据
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:list")
    @PostMapping("/systemSwapSizeFreeEcharts")
    public AjaxResult systemSwapSizeFreeEcharts(@RequestBody InitialSystemOtherCollectData initialSystemOtherCollectData) {
        Map<String, Object> echartsData = initialSystemOtherCollectDataService.systemSwapSizeFreeEcharts(initialSystemOtherCollectData);
        return success(echartsData);
    }

    /**
     * 查询内存利用率监控信息列表并封装为多折线ECharts图表数据
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:list")
    @PostMapping("/memoryUtilizationEcharts")
    public AjaxResult memoryUtilizationEcharts(@RequestBody InitialSystemOtherCollectData initialSystemOtherCollectData) {
        Map<String, Object> echartsData = initialSystemOtherCollectDataService.memoryUtilizationEcharts(initialSystemOtherCollectData);
        return success(echartsData);
    }

    /**
     * 查询可用交换空间百分比监控信息列表并封装为多折线ECharts图表数据
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:list")
    @PostMapping("/systemSwapSizePercentEcharts")
    public AjaxResult systemSwapSizePercentEcharts(@RequestBody InitialSystemOtherCollectData initialSystemOtherCollectData) {
        Map<String, Object> echartsData = initialSystemOtherCollectDataService.systemSwapSizePercentEcharts(initialSystemOtherCollectData);
        return success(echartsData);
    }

    /**
     * 查询可用内存监控信息列表并封装为多折线ECharts图表数据
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:list")
    @PostMapping("/memorySizeAvailableEcharts")
    public AjaxResult memorySizeAvailableEcharts(@RequestBody InitialSystemOtherCollectData initialSystemOtherCollectData) {
        Map<String, Object> echartsData = initialSystemOtherCollectDataService.memorySizeAvailableEcharts(initialSystemOtherCollectData);
        return success(echartsData);
    }

    /**
     * 查询可用内存百分比监控信息列表并封装为多折线ECharts图表数据
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:list")
    @PostMapping("/memorySizePercentEcharts")
    public AjaxResult memorySizePercentEcharts(@RequestBody InitialSystemOtherCollectData initialSystemOtherCollectData) {
        Map<String, Object> echartsData = initialSystemOtherCollectDataService.memorySizePercentEcharts(initialSystemOtherCollectData);
        return success(echartsData);
    }


    /**
     * 查询进程数监控信息列表并封装为多折线ECharts图表数据
     */
    @RequiresPermissions("rocketmq:systemOtherCollectData:list")
    @PostMapping("/procNumEcharts")
    public AjaxResult procNumEcharts(@RequestBody InitialSystemOtherCollectData initialSystemOtherCollectData) {
        Map<String, Object> echartsData = initialSystemOtherCollectDataService.procNumEcharts(initialSystemOtherCollectData);
        return success(echartsData);
    }
}
